pub struct RgbdTimeline<'a> { /* private fields */ }Expand description
Ordered, borrowed synchronized sensor timeline.
Implementations
Sourceimpl<'a> RgbdTimeline<'a>
impl<'a> RgbdTimeline<'a>
Sourcepub fn try_new(
frames: impl IntoIterator<Item = RgbdFrameView<'a>>,
max_skew_nanos: u64,
) -> ViewerResult<Self>
pub fn try_new( frames: impl IntoIterator<Item = RgbdFrameView<'a>>, max_skew_nanos: u64, ) -> ViewerResult<Self>
Creates a validated timeline in non-decreasing display timestamp order.
Sourcepub fn frames(&self) -> &[RgbdFrameView<'a>]
pub fn frames(&self) -> &[RgbdFrameView<'a>]
Ordered frames.
Sourcepub const fn max_skew_nanos(&self) -> u64
pub const fn max_skew_nanos(&self) -> u64
Configured maximum sensor skew.
Sourcepub fn nearest(&self, timestamp_nanos: u64) -> Option<RgbdFrameView<'a>>
pub fn nearest(&self, timestamp_nanos: u64) -> Option<RgbdFrameView<'a>>
Selects the nearest frame, preferring the earlier frame on ties.
Sourcepub fn inspect_pixel(
&self,
frame_index: usize,
x: usize,
y: usize,
camera: &PinholeCamera,
) -> ViewerResult<RgbdPixelSample>
pub fn inspect_pixel( &self, frame_index: usize, x: usize, y: usize, camera: &PinholeCamera, ) -> ViewerResult<RgbdPixelSample>
Inspects one pixel and unprojects valid depth with a pinhole camera.