pub struct StudioCalibration {
pub registration_ready: bool,
pub clock_status: String,
pub frame_status: String,
pub source_bound: bool,
pub blockers: Vec<String>,
}Expand description
Calibration admission state displayed by the Studio gate panel.
Fields
registration_ready: boolWhether both required calibration artifacts are registered and ready.
clock_status: StringClock-artifact status, for example registered or not_registered.
frame_status: StringFrame-artifact status, for example registered or not_registered.
source_bound: boolWhether the calibration evidence is bound to the displayed source.
blockers: Vec<String>Fail-closed reasons preventing calibration admission.
Implementations
Sourceimpl StudioCalibration
impl StudioCalibration
Sourcepub fn try_new(
registration_ready: bool,
clock_status: impl Into<String>,
frame_status: impl Into<String>,
source_bound: bool,
blockers: Vec<String>,
) -> ViewerResult<Self>
pub fn try_new( registration_ready: bool, clock_status: impl Into<String>, frame_status: impl Into<String>, source_bound: bool, blockers: Vec<String>, ) -> ViewerResult<Self>
Creates and validates a calibration gate state.
Sourcepub fn validate(&self) -> ViewerResult<()>
pub fn validate(&self) -> ViewerResult<()>
Validates that ready state has no unresolved blockers.